==> zego_uikit-2.14.0.tar.gz: lib/src/services/message_service.dart <==
part of 'uikit_service.dart';

/// @nodoc
mixin ZegoMessageService {
  /// send in-room message
  Future<bool> sendInRoomMessage(String message) async {
    final resultErrorCode =
        await ZegoUIKitCore.shared.coreMessage.sendBroadcastMessage(message);

    if (ZegoUIKitErrorCode.success != resultErrorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl.add(
        ZegoUIKitError(
          code: ZegoUIKitErrorCode.messageSendError,
          message: 'send in-room message error:$resultErrorCode, '
              'message:$message, '
              '${ZegoUIKitErrorCode.expressErrorCodeDocumentTips}',
          method: 'sendInRoomCommand',
        ),
      );
    }

    return ZegoErrorCode.CommonSuccess == resultErrorCode;
  }

  /// re-send in-room message
  Future<bool> resendInRoomMessage(ZegoInRoomMessage message) async {
    final resultErrorCode =
        await ZegoUIKitCore.shared.coreMessage.resendInRoomMessage(message);

    if (ZegoUIKitErrorCode.success != resultErrorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl.add(
        ZegoUIKitError(
          code: ZegoUIKitErrorCode.messageReSendError,
          message: 'resend in-room message error:$resultErrorCode, '
              'message:$message, '
              '${ZegoUIKitErrorCode.expressErrorCodeDocumentTips}',
          method: 'sendInRoomCommand',
        ),
      );
    }

    return ZegoErrorCode.CommonSuccess == resultErrorCode;
  }

  /// get in-room messages
  List<ZegoInRoomMessage> getInRoomMessages() {
    return ZegoUIKitCore.shared.coreMessage.messageList;
  }

  /// get in-room messages notifier
  Stream<List<ZegoInRoomMessage>> getInRoomMessageListStream() {
    return ZegoUIKitCore.shared.coreMessage.streamControllerMessageList.stream;
  }

  /// get in-room messages one-by-one notifier
  Stream<ZegoInRoomMessage> getInRoomMessageStream() {
    return ZegoUIKitCore
        .shared.coreMessage.streamControllerRemoteMessage.stream;
  }

  /// get in-room messages one-by-one notifier
  Stream<ZegoInRoomMessage> getInRoomLocalMessageStream() {
    return ZegoUIKitCore.shared.coreMessage.streamControllerLocalMessage.stream;
  }
}

==> zego_uikit-2.15.6.tar.gz: lib/src/services/message_service.dart <==
part of 'uikit_service.dart';

/// @nodoc
mixin ZegoMessageService {
  /// send in-room message
  Future<bool> sendInRoomMessage(String message) async {
    final resultErrorCode =
        await ZegoUIKitCore.shared.coreMessage.sendBroadcastMessage(message);

    if (ZegoUIKitErrorCode.success != resultErrorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl?.add(
        ZegoUIKitError(
          code: ZegoUIKitErrorCode.messageSendError,
          message: 'send in-room message error:$resultErrorCode, '
              'message:$message, '
              '${ZegoUIKitErrorCode.expressErrorCodeDocumentTips}',
          method: 'sendInRoomCommand',
        ),
      );
    }

    return ZegoErrorCode.CommonSuccess == resultErrorCode;
  }

  /// re-send in-room message
  Future<bool> resendInRoomMessage(ZegoInRoomMessage message) async {
    final resultErrorCode =
        await ZegoUIKitCore.shared.coreMessage.resendInRoomMessage(message);

    if (ZegoUIKitErrorCode.success != resultErrorCode) {
      ZegoUIKitCore.shared.coreData.errorStreamCtrl?.add(
        ZegoUIKitError(
          code: ZegoUIKitErrorCode.messageReSendError,
          message: 'resend in-room message error:$resultErrorCode, '
              'message:$message, '
              '${ZegoUIKitErrorCode.expressErrorCodeDocumentTips}',
          method: 'sendInRoomCommand',
        ),
      );
    }

    return ZegoErrorCode.CommonSuccess == resultErrorCode;
  }

  /// get in-room messages
  List<ZegoInRoomMessage> getInRoomMessages() {
    return ZegoUIKitCore.shared.coreData.messageList;
  }

  /// get in-room messages notifier
  Stream<List<ZegoInRoomMessage>> getInRoomMessageListStream() {
    return ZegoUIKitCore.shared.coreData.streamControllerMessageList?.stream ??
        const Stream.empty();
  }

  /// get in-room messages one-by-one notifier
  Stream<ZegoInRoomMessage> getInRoomMessageStream() {
    return ZegoUIKitCore
            .shared.coreData.streamControllerRemoteMessage?.stream ??
        const Stream.empty();
  }

  /// get in-room messages one-by-one notifier
  Stream<ZegoInRoomMessage> getInRoomLocalMessageStream() {
    return ZegoUIKitCore.shared.coreData.streamControllerLocalMessage?.stream ??
        const Stream.empty();
  }
}
